/* Editor_enums.h
 *
 * Copyright (C) 1992-2007,2013,2015,2017 Paul Boersma
 *
 * This code is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 *
 * This code is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this work. If not, see <http://www.gnu.org/licenses/>.
 */

enums_begin (kEditor_writeNameAtTop, 0)
	enums_add (kEditor_writeNameAtTop, 0, NO_, U"no")
	enums_add (kEditor_writeNameAtTop, 1, FAR_, U"far")
	enums_add (kEditor_writeNameAtTop, 2, NEAR_, U"near")
enums_end (kEditor_writeNameAtTop, 2, FAR_)

/* End of file Editor_enums.h */
